Module storage

Module storage 

This module contains all the different types of storages.

For details on specific behavior, see the documentation of each storage.

Re-exports

pub use local_storage::LocalStorage;
pub use shared_storage::SharedStorage;

Modules

local_storage
This module defines and implements in-memory, branch-local storage.
shared_storage
This module defines and implements in-memory, shared storage.