MergeResult

Enum MergeResult 

pub enum MergeResult<T> {
    KeepParent,
    ReplaceOrInsert(T),
    Remove,
}
Represents the result of merging multiple instances of a type during context merging.

This enum is used by the Merge trait to determine how merging should affect the parent value. It is up to the implementor to decide whether to keep, replace, or remove it entirely.

See also Merge trait.

Variants



KeepParent

Keep the existing parent value as-is, whether it exists or not.



ReplaceOrInsert(T)

Replace the parent value or insert this value if it does not exist.



Remove

Remove the value from the parent context entirely.