Module shared_storage

Module shared_storage 

This module defines and implements in-memory, shared storage.

It is used for managing node of flow state shared across branches, where the items have only one instance thats is shared across all branches.

For details and examples see the documentation of SharedStorage.

Structs

SharedStorageImplshared_storage_impl
An implementation of type-based shared storage.

Traits

SharedStorage
Provides type-based shared storage for concurrent environments.