DescriptionBase

Struct DescriptionBase 

pub struct DescriptionBase {
    pub type: Type,
    pub input: Type,
    pub output: Type,
    pub error: Type,
    pub context: Type,
    pub description: Option<String>,
    pub externals: Option<Vec<ExternalResource>>,
}
The base structure describing a node’s type signature and metadata.

Contains information about the node’s input, output, error, and context types, along with optional description and external resource metadata.

Fields

type: Type

The type of the node or flow itself.

input: Type

The type of input accepted by the node.

output: Type

The type of output produced by the node.

error: Type

The type of error that may be returned by the node.

context: Type

The type of context used when executing the node.

description: Option<String>

An optional description of the node or flow.

externals: Option<Vec<ExternalResource>>

Optional list of external resources the node uses.

Implementations

Source

impl DescriptionBase

pub fn from<NodeType, Input, Output, Error, Context>() -> Self

Creates a DescriptionBase from type parameters.

pub fn from_node<NodeType, Input, Output, Error, Context>( _node: &NodeType, ) -> Self
where NodeType: Node<Input, NodeOutput<Output>, Error, Context>,

Creates a DescriptionBase from a given Node instance.

pub fn with_description(self, description: impl Into<String>) -> Self

Sets a description.

This is primarily used to provide additional documentation or context.

pub fn with_externals(self, externals: Vec<ExternalResource>) -> Self

Sets the external resources.

External resources could include remote calls, file accesses or other types of external services.