Module flows

Module flows 

This module contains all the different types of flows.

For details on specific behavior, see the documentation of each flow.

Re-exports

pub use sequential_flow::SequentialFlow;
pub use one_of_sequential_flow::OneOfSequentialFlow;
pub use one_of_parallel_flow::OneOfParallelFlow;
pub use parallel_flow::ParallelFlow;
pub use fn_flow::FnFlow;
pub use detached::Detached;

Modules

detached
This module contains everything needed for constructing Detached.
fn_flow
This module contains everything needed for constructing FnFlow.
one_of_parallel_flow
This module contains everything needed for constructing OneOfParallelFlow.
one_of_sequential_flow
This module contains everything needed for constructing OneOfSequentialFlow.
parallel_flow
This module contains everything needed for constructing ParallelFlow.
sequential_flow
This module contains everything needed for constructing SequentialFlow.